[vRFC,4/8] treewide: rename firmware_request_cache()

Message ID 20240222180033.23775-5-quic_mojha@quicinc.com
State New
Headers
Series Refactor and rename request firmware API |

Commit Message

Mukesh Ojha Feb. 22, 2024, 6 p.m. UTC
  Rename firmware_request_cache() to request_firmware_cache()
to be more concrete and align with the name of other request
firmware family functions.

Signed-off-by: Mukesh Ojha <quic_mojha@quicinc.com>
---
 Documentation/driver-api/firmware/request_firmware.rst | 6 +++---
 drivers/base/firmware_loader/main.c                    | 6 +++---
 drivers/net/wireless/mediatek/mt7601u/mcu.c            | 2 +-
 include/linux/firmware.h                               | 2 +-
 4 files changed, 8 insertions(+), 8 deletions(-)
  

Patch

diff --git a/Documentation/driver-api/firmware/request_firmware.rst b/Documentation/driver-api/firmware/request_firmware.rst
index 3d6df9922c4b..6c5b91705bb3 100644
--- a/Documentation/driver-api/firmware/request_firmware.rst
+++ b/Documentation/driver-api/firmware/request_firmware.rst
@@ -60,13 +60,13 @@  Special optimizations on reboot
 Some devices have an optimization in place to enable the firmware to be
 retained during system reboot. When such optimizations are used the driver
 author must ensure the firmware is still available on resume from suspend,
-this can be done with firmware_request_cache() instead of requesting for the
+this can be done with request_firmware_cache() instead of requesting for the
 firmware to be loaded.
 
-firmware_request_cache()
+request_firmware_cache()
 ------------------------
 .. kernel-doc:: drivers/base/firmware_loader/main.c
-   :functions: firmware_request_cache
+   :functions: request_firmware_cache
 
 request firmware API expected driver use
 ========================================
diff --git a/drivers/net/wireless/mediatek/mt7601u/mcu.c b/drivers/net/wireless/mediatek/mt7601u/mcu.c
index 1b5cc271a9e1..cee36dc1e9eb 100644
--- a/drivers/net/wireless/mediatek/mt7601u/mcu.c
+++ b/drivers/net/wireless/mediatek/mt7601u/mcu.c
@@ -414,7 +414,7 @@  static int mt7601u_load_firmware(struct mt7601u_dev *dev)
 					 MT_USB_DMA_CFG_TX_BULK_EN));
 
 	if (firmware_running(dev))
-		return firmware_request_cache(dev->dev, MT7601U_FIRMWARE);
+		return request_firmware_cache(dev->dev, MT7601U_FIRMWARE);
 
 	ret = request_firmware(&fw, MT7601U_FIRMWARE, dev->dev);
 	if (ret)
diff --git a/include/linux/firmware.h b/include/linux/firmware.h
index 93e6a37352a8..4449837ea0c6 100644
--- a/include/linux/firmware.h
+++ b/include/linux/firmware.h
@@ -196,6 +196,6 @@  static inline void firmware_upload_unregister(struct fw_upload *fw_upload)
 
 #endif
 
-int firmware_request_cache(struct device *device, const char *name);
+int request_firmware_cache(struct device *device, const char *name);
 
 #endif
diff --git a/drivers/base/firmware_loader/main.c b/drivers/base/firmware_loader/main.c
index 9411ad7968cb..2823dcd7153a 100644
--- a/drivers/base/firmware_loader/main.c
+++ b/drivers/base/firmware_loader/main.c
@@ -1034,7 +1034,7 @@  int request_firmware_platform(const struct firmware **firmware,
 EXPORT_SYMBOL_GPL(request_firmware_platform);
 
 /**
  * firmware_request_cache() - cache firmware for suspend so resume can use it
  * @name: name of firmware file
  * @device: device for which firmware should be cached for
  *
@@ -1045,7 +1045,7 @@  EXPORT_SYMBOL_GPL(request_firmware_platform);
  * situations. This helper is not compatible with drivers which use
  * request_firmware_into_buf() or request_firmware_nowait() with no uevent set.
  **/
-int firmware_request_cache(struct device *device, const char *name)
+int request_firmware_cache(struct device *device, const char *name)
 {
 	int ret;
 
@@ -1055,7 +1055,7 @@  int firmware_request_cache(struct device *device, const char *name)
 
 	return ret;
 }
-EXPORT_SYMBOL_GPL(firmware_request_cache);
+EXPORT_SYMBOL_GPL(request_firmware_cache);
 
 /**
  * request_firmware_into_buf() - load firmware into a previously allocated buffer
@@ -1034,7 +1034,7 @@  int request_firmware_platform(const struct firmware **firmware,
 
 /**
- * firmware_request_cache() - cache firmware for suspend so resume can use it
+ * request_firmware_cache() - cache firmware for suspend so resume can use it
  * @name: name of firmware file
  * @device: device for which firmware should be cached for